@@ -1,9 +1,11 @@
 from seqtk._concatenate import concatenate
 from seqtk._gather import gather
 from seqtk._map import map
+from seqtk._split_every import split_every
 
 __all__ = [
     "concatenate",
     "gather",
     "map",
+    "split_every",
 ]
